==> plantuml-libs-5.2.0.tgz: package/distribution/azure-4/Item/General/ServiceCommit.md <==
# ServiceCommit


```text
azure-4/Item/General/ServiceCommit
```

```text
include('azure-4/Item/General/ServiceCommit')
```



| Illustration | ServiceCommit | ServiceCommitCard | ServiceCommitGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../azure-4/Item/General/ServiceCommit.png) | ![illustration for ServiceCommit](../../../azure-4/Item/General/ServiceCommit.Local.png) | ![illustration for ServiceCommitCard](../../../azure-4/Item/General/ServiceCommitCard.Local.png) | ![illustration for ServiceCommitGroup](../../../azure-4/Item/General/ServiceCommitGroup.Local.png) |




## ServiceCommit

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceCommit
include('azure-4/Item/General/ServiceCommit')

' renders the element
ServiceCommit('ServiceCommit', 'Service Commit', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceCommit
include('azure-4/Item/General/ServiceCommit')

' renders the element
ServiceCommit('ServiceCommit', 'Service Commit', 'an optional tech label')
@enduml
```

## ServiceCommitCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceCommitCard
include('azure-4/Item/General/ServiceCommit')

' renders the element
ServiceCommitCard('ServiceCommitCard', 'Service Commit Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceCommitCard
include('azure-4/Item/General/ServiceCommit')

' renders the element
ServiceCommitCard('ServiceCommitCard', 'Service Commit Card', 'an optional description')
@enduml
```

## ServiceCommitGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://github.com/tmorin/plantuml-libs/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceCommitGroup
include('azure-4/Item/General/ServiceCommit')

' renders the element
ServiceCommitGroup('ServiceCommitGroup', 'Service Commit Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceCommitGroup
include('azure-4/Item/General/ServiceCommit')

' renders the element
ServiceCommitGroup('ServiceCommitGroup', 'Service Commit Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

==> plantuml-libs-6.4.0.tgz: package/distribution/azure-4/Item/General/ServiceCommit.md <==
# ServiceCommit


```text
azure-4/Item/General/ServiceCommit
```

```text
include('azure-4/Item/General/ServiceCommit')
```



| Illustration | ServiceCommit | ServiceCommitCard | ServiceCommitGroup |
| :---: | :---: | :---: | :---: |
| ![illustration for Illustration](../../../azure-4/Item/General/ServiceCommit.png) | ![illustration for ServiceCommit](../../../azure-4/Item/General/ServiceCommit.Local.png) | ![illustration for ServiceCommitCard](../../../azure-4/Item/General/ServiceCommitCard.Local.png) | ![illustration for ServiceCommitGroup](../../../azure-4/Item/General/ServiceCommitGroup.Local.png) |




## ServiceCommit

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceCommit
include('azure-4/Item/General/ServiceCommit')

' renders the element
ServiceCommit('ServiceCommit', 'Service Commit', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceCommit
include('azure-4/Item/General/ServiceCommit')

' renders the element
ServiceCommit('ServiceCommit', 'Service Commit', 'an optional tech label')
@enduml
```

## ServiceCommitCard

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceCommitCard
include('azure-4/Item/General/ServiceCommit')

' renders the element
ServiceCommitCard('ServiceCommitCard', 'Service Commit Card', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceCommitCard
include('azure-4/Item/General/ServiceCommit')

' renders the element
ServiceCommitCard('ServiceCommitCard', 'Service Commit Card', 'an optional description')
@enduml
```

## ServiceCommitGroup

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceCommitGroup
include('azure-4/Item/General/ServiceCommit')

' renders the element
ServiceCommitGroup('ServiceCommitGroup', 'Service Commit Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('azure-4/bootstrap')

' loads the Item which embeds the element ServiceCommitGroup
include('azure-4/Item/General/ServiceCommit')

' renders the element
ServiceCommitGroup('ServiceCommitGroup', 'Service Commit Group', 'an optional tech label') {
    note as note
        the content of the group
    end note
}
@enduml
```
